package org.iotivity.bridge.homeserver.handler.client;

import android.util.Log;

import org.iotivity.OCClientResponse;
import org.iotivity.OCRep;
import org.iotivity.OCRepresentation;
import org.iotivity.OCResponseHandler;
import org.iotivity.OCStatus;
import org.iotivity.bridge.homeserver.BridgeServerActivity;
import org.iotivity.bridge.homeserver.BridgeService;
import org.iotivity.bridge.homeserver.model.Light;
import org.iotivity.bridge.homeserver.utils.Utils;
import org.iotivity.oc.OcRemoteResource;
import org.json.JSONException;
import org.json.JSONObject;

public class PostResponseHandler implements OCResponseHandler {

    private static final String TAG = PostResponseHandler.class.getSimpleName();

    private BridgeService service ;
    private OcRemoteResource resource ;

    public PostResponseHandler(BridgeService service, OcRemoteResource resource) {
        this.service = service;
        this.resource = resource ;
    }

    @Override
    public void handler(OCClientResponse response) {

        Log.d(TAG, "POST "+resource.getUri()+" Response Handler: Code = "+response.getCode().toString());
        if(response.getCode() != OCStatus.OC_STATUS_CHANGED && response.getCode() != OCStatus.OC_STATUS_CREATED) {
            return;
        }

        try {

            JSONObject result = new JSONObject();
            result.put("id", resource.getAnchor() + resource.getUri());
            result.put("di", Utils.getDIFromAnchor(resource.getAnchor()));
            result.put("uri", resource.getUri());
            result.put("res_type", BridgeService.ResponseType.POST.name());

            String result_str = result.toString().replace("\\", "");
            service.broadcastResult(BridgeService.ResultType.OK.ordinal(), result_str);

        } catch (JSONException ex) {
            Log.e(TAG, "JSON Error : ", ex);
        }
    }
}
